package com.tianyi.config;

import com.tianyi.interceptor.SignInterceptor;
import org.springframework.context.annotation.Configuration;
import org.springframework.web.servlet.config.annotation.InterceptorRegistry;
import org.springframework.web.servlet.config.annotation.ResourceHandlerRegistry;
import org.springframework.web.servlet.config.annotation.WebMvcConfigurationSupport;

import java.util.ArrayList;
import java.util.List;


@Configuration
public class WebMvcConfig extends WebMvcConfigurationSupport {

    private final SignInterceptor signInterceptor;

    public WebMvcConfig(SignInterceptor signInterceptor) {
        this.signInterceptor = signInterceptor;
    }

    /**
     * WebMvc配置
     * @param registry
     */
    public void addInterceptors(InterceptorRegistry registry) {
        //不拦截的地址
        List<String> excludeUrlList = new ArrayList<>();
        excludeUrlList.add("/swagger-ui.html");
        excludeUrlList.add("/swagger-ui.html/**");
        excludeUrlList.add("/webjars/**");
        excludeUrlList.add("/swagger/**");
        excludeUrlList.add("/doc.html");
        excludeUrlList.add("/doc.html/**");
        excludeUrlList.add("/swagger-resources/**");
        excludeUrlList.add("/v2/**");
        excludeUrlList.add("/favicon.ico");
        excludeUrlList.add("/getfile/**");
        //生成应用id和密钥接口不拦截
        excludeUrlList.add("/secret");
        registry.addInterceptor(signInterceptor)
                //拦截所有请求
                .addPathPatterns("/**")
                //排除的请求
                .excludePathPatterns(excludeUrlList);
        super.addInterceptors(registry);
    }
    private static final String[] CLASSPATH_RESOURCE_LOCATIONS = {
            "classpath:/META-INF/resources/", "classpath:/resources/",
            "classpath:/static/", "classpath:/public/" };


    @Override
    public void addResourceHandlers(ResourceHandlerRegistry registry) {
        if (!registry.hasMappingForPattern("/webjars/**")) {
            registry.addResourceHandler("/webjars/**").addResourceLocations(
                    "classpath:/META-INF/resources/webjars/");
        }
        if (!registry.hasMappingForPattern("/**")) {
            registry.addResourceHandler("/**").addResourceLocations(
                    CLASSPATH_RESOURCE_LOCATIONS);
        }

    }
}
