package com.tianyi.service.impl;


import com.alibaba.fastjson.JSONObject;
import com.tianyi.mapper.SecretMapper;
import com.tianyi.model.RequestModel;
import com.tianyi.model.SecretModel;
import com.tianyi.service.PdfToOfdService;
import lombok.SneakyThrows;
import org.apache.commons.lang3.StringUtils;
import org.apache.pdfbox.pdmodel.PDDocument;
import org.apache.pdfbox.pdmodel.common.PDRectangle;
import org.apache.pdfbox.rendering.PDFRenderer;
import org.ofdrw.graphics2d.OFDGraphicsDocument;
import org.ofdrw.graphics2d.OFDPageGraphics2D;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.stereotype.Service;
import org.springframework.util.ObjectUtils;

import javax.servlet.http.HttpServletRequest;
import java.io.ByteArrayOutputStream;
import java.io.InputStream;
import java.net.*;
import java.nio.file.Files;
import java.nio.file.Path;
import java.nio.file.Paths;

@Service
public class PdfToOfdServiceImpl implements PdfToOfdService {

    private static final Logger log = LoggerFactory.getLogger(PdfToOfdServiceImpl.class);

    private final SecretMapper secretMapper;

    public PdfToOfdServiceImpl(SecretMapper secretMapper) {
        this.secretMapper = secretMapper;
    }

    @Override
    @SneakyThrows
    public Object convert(RequestModel requestModel, HttpServletRequest request) {
        JSONObject jsonObject = new JSONObject();
        SecretModel secretModel = secretMapper.getAllByOrg(request.getHeader("org"));
        if (ObjectUtils.isEmpty(secretModel)) {
            jsonObject.put("code", "500");
            jsonObject.put("msg", "无权限访问!");
            return jsonObject;
        }
        URL url = new URL(requestModel.getUrlStr());
        URLConnection urlConnection = url.openConnection();
        InputStream inputStream = urlConnection.getInputStream();
        ByteArrayOutputStream outputStream = new ByteArrayOutputStream();
        try (OFDGraphicsDocument ofdDoc = new OFDGraphicsDocument(outputStream); PDDocument pdfDoc = PDDocument.load(inputStream)) {
            PDFRenderer pdfRender = new PDFRenderer(pdfDoc);
            for (int pageIndex = 0; pageIndex < pdfDoc.getNumberOfPages(); pageIndex++) {
                PDRectangle pdfPageSize = pdfDoc.getPage(pageIndex).getBBox();
                OFDPageGraphics2D ofdPageG2d = ofdDoc.newPage(pdfPageSize.getWidth(), pdfPageSize.getHeight());
                pdfRender.renderPageToGraphics(pageIndex, ofdPageG2d);
            }
        }
        Path out;
        String os = System.getProperty("os.name").toLowerCase();
        log.error("系统类别:{}", os);
        if (StringUtils.contains(os, "linux")) {
            long time = System.currentTimeMillis();
            out = Paths.get("/home/ofd/ofddir/" + time + ".ofd");
            Files.write(out, outputStream.toByteArray());
            jsonObject.put("code", "200");
            jsonObject.put("msg", "转换成功!");
            return jsonObject;
        }
        if (StringUtils.contains(os, "windows")) {
            out = Paths.get("target", System.currentTimeMillis() + ".ofd");
            Files.write(out, outputStream.toByteArray());
            URI uri = out.toUri();
            return uri.getPath();
        }
        return null;
    }


}
